==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkProgrammableFilter.java <==
// java wrapper for vtkProgrammableFilter object
//

package vtk;
import vtk.*;

public class vtkProgrammableFilter extends vtkPassInputTypeAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetExecuteMethod_2(Object id0, String id1);
  public void SetExecuteMethod(Object id0, String id1)
    { SetExecuteMethod_2(id0,id1); }

  private native long GetPolyDataInput_3();
  public vtkPolyData GetPolyDataInput() {
    long temp = GetPolyDataInput_3();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredPointsInput_4();
  public vtkStructuredPoints GetStructuredPointsInput() {
    long temp = GetStructuredPointsInput_4();

    if (temp == 0) return null;
    return (vtkStructuredPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredGridInput_5();
  public vtkStructuredGrid GetStructuredGridInput() {
    long temp = GetStructuredGridInput_5();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetUnstructuredGridInput_6();
  public vtkUnstructuredGrid GetUnstructuredGridInput() {
    long temp = GetUnstructuredGridInput_6();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRectilinearGridInput_7();
  public vtkRectilinearGrid GetRectilinearGridInput() {
    long temp = GetRectilinearGridInput_7();

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetGraphInput_8();
  public vtkGraph GetGraphInput() {
    long temp = GetGraphInput_8();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTableInput_9();
  public vtkTable GetTableInput() {
    long temp = GetTableInput_9();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCopyArrays_10(boolean id0);
  public void SetCopyArrays(boolean id0)
    { SetCopyArrays_10(id0); }

  private native boolean GetCopyArrays_11();
  public boolean GetCopyArrays()
    { return GetCopyArrays_11(); }

  private native void CopyArraysOn_12();
  public void CopyArraysOn()
    { CopyArraysOn_12(); }

  private native void CopyArraysOff_13();
  public void CopyArraysOff()
    { CopyArraysOff_13(); }

  public vtkProgrammableFilter() { super(); }

  public vtkProgrammableFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.2-2-armv7h.pkg.tar.xz: vtk/vtkProgrammableFilter.java <==
// java wrapper for vtkProgrammableFilter object
//

package vtk;
import vtk.*;

public class vtkProgrammableFilter extends vtkPassInputTypeAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetExecuteMethod_2(Object id0, String id1);
  public void SetExecuteMethod(Object id0, String id1)
    { SetExecuteMethod_2(id0,id1); }

  private native long GetPolyDataInput_3();
  public vtkPolyData GetPolyDataInput() {
    long temp = GetPolyDataInput_3();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredPointsInput_4();
  public vtkStructuredPoints GetStructuredPointsInput() {
    long temp = GetStructuredPointsInput_4();

    if (temp == 0) return null;
    return (vtkStructuredPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredGridInput_5();
  public vtkStructuredGrid GetStructuredGridInput() {
    long temp = GetStructuredGridInput_5();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetUnstructuredGridInput_6();
  public vtkUnstructuredGrid GetUnstructuredGridInput() {
    long temp = GetUnstructuredGridInput_6();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetRectilinearGridInput_7();
  public vtkRectilinearGrid GetRectilinearGridInput() {
    long temp = GetRectilinearGridInput_7();

    if (temp == 0) return null;
    return (vtkRectilinearGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetGraphInput_8();
  public vtkGraph GetGraphInput() {
    long temp = GetGraphInput_8();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetTableInput_9();
  public vtkTable GetTableInput() {
    long temp = GetTableInput_9();

    if (temp == 0) return null;
    return (vtkTable)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetCopyArrays_10(boolean id0);
  public void SetCopyArrays(boolean id0)
    { SetCopyArrays_10(id0); }

  private native boolean GetCopyArrays_11();
  public boolean GetCopyArrays()
    { return GetCopyArrays_11(); }

  private native void CopyArraysOn_12();
  public void CopyArraysOn()
    { CopyArraysOn_12(); }

  private native void CopyArraysOff_13();
  public void CopyArraysOff()
    { CopyArraysOff_13(); }

  public vtkProgrammableFilter() { super(); }

  public vtkProgrammableFilter(long id) { super(id); }
  public native long   VTKInit();

}
